diff --git a/game/engines/default/engine/interface/ActorAI.lua b/game/engines/default/engine/interface/ActorAI.lua
index 4afe6c3e4fae0b43b09ca4a826ada36d1649452d..d8437583625052cfda1423ec51feb119d19462c3 100644
--- a/game/engines/default/engine/interface/ActorAI.lua
+++ b/game/engines/default/engine/interface/ActorAI.lua
@@ -163,8 +163,14 @@ function _M:aiSeeTargetPos(target)
 	local LSeen = self.ai_state.target_last_seen
 	if type(LSeen) ~= "table" then return tx, ty end
 	local spread = 0
-	LSeen.GCache_turn = LSeen.GCache_turn or game.turn -- Guess Cache turn to update position guess (so it's consistent during a turn)
-	LSeen.GCknown_turn = LSeen.GCknown_turn or game.turn -- Guess Cache known turn for spread calculation (self.ai_state.target_last_seen.turn can't be used because it's needed by FOV code)
+
+	-- Guess Cache turn to update position guess (so it's consistent during a turn)
+	-- Start at -1000 to make sure ti gets run the first time.
+	LSeen.GCache_turn = LSeen.GCache_turn or game.turn - 1000
+
+	-- Guess Cache known turn for spread calculation (self.ai_state.target_last_seen.turn
+	-- can't be used because it's needed by FOV code)
+	LSeen.GCknown_turn = LSeen.GCknown_turn or game.turn - 1000
 
 	-- Check if target is currently seen
 	local see, chance = self:canSee(target)
@@ -187,4 +193,4 @@ function _M:aiSeeTargetPos(target)
 		if LSeen.GCache_x then return LSeen.GCache_x, LSeen.GCache_y end
 	end
 	return tx, ty -- Fall through to correct coords
-end
\ No newline at end of file
+end